import React, { useState, useEffect } from 'react';
import { View, Text, Button, Image, TouchableOpacity, StyleSheet, TouchableHighlight, Alert, Modal } from 'react-native';
import * as ImagePicker from 'expo-image-picker';
import axios from 'axios';
import { Camera } from 'expo-camera';
import { useNavigation } from '@react-navigation/native';
import { LogBox } from 'react-native';


// Ignore log notification by message
LogBox.ignoreLogs(['Warning: ...']);

//Ignore all log notifications
LogBox.ignoreAllLogs();

const baseUrl = 'http://192.168.8.105:5000';
const endpoint = '/upload';

const AreaCalculationScreen = () => {

    const navigation = useNavigation();
    const [imageUri, setImageUri] = useState(null);
    const [afflictionPercentage, setAfflictionPercentage] = useState(null);
    const [cameraPermission, setCameraPermission] = useState(null);
    const [cameraType, setCameraType] = useState(Camera.Constants.Type.back);
    const [showCamera, setShowCamera] = useState(false);
    const [isModalVisible, setIsModalVisible] = useState(false);
    const [isErrorModalVisible, setIsErrorModalVisible] = useState(false);
    const [errorModalMessage, setErrorModalMessage] = useState('');

    const getAfflictionMessage = (percentage) => {
      if (percentage >= 60 && percentage <= 100) {
          return { message: "Use as mother plant", image: require('./assets/motherPlant.png') };
      } else if (percentage >= 30 && percentage < 60) {
          return { message: "Sell it in local market", image: require('./assets/localMarket.png') };
      } else {
          return { message: "Can export", image: require('./assets/export.png') };
      }
    }
    

   




    useEffect(() => {
        (async () => {
          const { status } = await Camera.requestPermissionsAsync();
          setCameraPermission(status === 'granted');
        })();
      }, []);
    
      const handleImagePicker = async () => {
        const permissionResult = await ImagePicker.requestMediaLibraryPermissionsAsync();
    
        if (permissionResult.granted === false) {
          showError('Permission to access media library is required!');
          return;
        }
    
        const imageResult = await ImagePicker.launchImageLibraryAsync();
        
        if (!imageResult.cancelled) {
          setImageUri(imageResult.uri);
          setAfflictionPercentage('');
          setShowCamera(false);
        }
      };
    
      const handleCapture = async () => {
        if (camera) {
          const photo = await camera.takePictureAsync();

          

          setImageUri(photo.uri);
          setAfflictionPercentage('');
          setShowCamera(false);
        }
      };
    
      const handleCameraPress = () => {
        setImageUri(null); // Reset the imageUri when switching to the camera
        setAfflictionPercentage(''); // Reset the prediction when switching to the camera
        setShowCamera(true);
      };
    
    
      const handleCancelCamera = () => {
        setShowCamera(false);
      };

      const showError = (message) => {
        setErrorModalMessage(message);
        setIsErrorModalVisible(true);
      };
      
    
      const calcArea = async () => {
        if (!imageUri) {
          showError('Please select an image first.');
          return;
        }
    
        try {
          const formData = new FormData();
          formData.append('file', {
            uri: imageUri,
            name: 'uploaded.jpg',
            type: 'image/jpeg',
          });
    
          const response = await axios.post(`${baseUrl}${endpoint}`, formData);
          if (response.data.success) {
            setAfflictionPercentage(response.data.affliction_percentage);
            setIsModalVisible(true);

          } else {
            // Handle the error from the backend
            showError(response.data.error);
          }
    
        } catch (error) {
          showError("Something went wrong while processing the image.");
        }
      };
    
      let camera;
    
      const navigateToApp = () => {
        navigation.goBack(); // Navigate back to the previous screen (App.js)
      };
    
      return (
        <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
          
    
          {showCamera && cameraPermission && (
            // <Camera style={{ width: 400, height: 600 }} type={cameraType} ref={ref => (camera = ref)}>
            <Camera style={{ width: 400, height: 800 }} type={cameraType} ref={ref => (camera = ref)} hideTopBar={true}>
              <View style={{ flex: 1, justifyContent: 'flex-end', alignItems: 'center' }}>
              <View style={styles.cameraButtons}>
                  <TouchableOpacity onPress={handleCapture} style={styles.captureButton}>
                    <Text style={styles.buttonText}>CAPTURE</Text>
                  </TouchableOpacity>
    
                  <TouchableOpacity onPress={handleCancelCamera} style={styles.cancelButton}>
                    <Text style={styles.buttonText}>CANCEL</Text>
                  </TouchableOpacity>
                </View>
              </View>
            </Camera>
          )}
    
          {/* {imageUri && <Image source={{ uri: imageUri }} style={styles.imageBox} />} */}
          {!showCamera && (
             <View style={styles.imageBox} underlayColor="#e8fbe8">
            

              {imageUri ? (
                  <View style={{ position: 'relative' }}>

                <Image
                  source={{ uri: imageUri }}
                  style={{ width: '100%', height: '100%', resizeMode: 'cover', borderRadius: 8 }}
                />
                <TouchableOpacity 
      style={styles.closeButton}
      onPress={() => setImageUri(null)}>
      <Text style={styles.closeButtonText}>✕</Text>
    </TouchableOpacity>
  </View>
              ) : (
                <>
                  <Image source={require('./assets/calcPlaceHolder.png')} style={styles.placeholderImage} />
                  <Text style={styles.placeholderText}>Capture an Image</Text>
                </>
              )}
            </View>
          )}
    
          <View style={styles.container}>
            {/* <Button title="Camera" onPress={handleCameraPress} />
             */}
    
             <TouchableHighlight style={styles.customButton} onPress={handleCameraPress} underlayColor="#e8fbe8">
             <Text style={styles.customButtonText}>Capture a Photo</Text>
             </TouchableHighlight>
    
            {/* <Button title="Gallery" onPress={handleImagePicker} /> */}
            <TouchableHighlight style={styles.customButton} onPress={handleImagePicker} underlayColor="#e8fbe8">
             <Text style={styles.customButtonText}>Select from Gallery</Text>
             </TouchableHighlight>
    
          </View>
    
          {imageUri && (
            <TouchableHighlight style={styles.button} onPress={calcArea} underlayColor="#e8fbe8">
              <Text style={styles.buttonText}>Calculate the Area</Text>
            </TouchableHighlight>
          
            
          )}
{/* Affliction Percentage Modal */}
<Modal
      animationType="slide"
      transparent={true}
      visible={isModalVisible}
      onRequestClose={() => {
          setIsModalVisible(false);
      }}
    >
      <View style={styles.overlay}>
        <View style={styles.centeredView}>
            <View style={styles.modalView}>
            <View style={styles.resultBox}>
                                {imageUri && (
                                    <Image
                                        source={{ uri: imageUri }}
                                        style={styles.modalImage}
                                    />
                                )}
                                <Text style={styles.afflictionText}>
                                    Affliction Percentage: {afflictionPercentage}%
                                </Text>
                            </View>
            {/* {imageUri && (
                <Image
                    source={{ uri: imageUri }}
                    style={styles.modalImage}
                />
            )} */}

              {/* {imageUri && (
                <>
                  <Image
                    source={{ uri: imageUri }}
                    style={styles.modalImage}
                    />
                    <Image 
                      source={require('./assets/calcPlaceHolder.png')} 
                      style={{ width: 50, height: 50, margin: 10 }} 
                    />
                  </>
                )}

            <Text style={styles.afflictionText}>Affliction Percentage: {afflictionPercentage}%</Text>
            <Text style={styles.afflictionText}>
                                {getAfflictionMessage(afflictionPercentage)}
                            </Text> */}

<View style={styles.recommendationBox}>
    <Image 
        source={getAfflictionMessage(afflictionPercentage).image} 
        style={{ width: 50, height: 50, margin: 10 }} 
    />
    <Text style={styles.afflictionText}>
        {getAfflictionMessage(afflictionPercentage).message}
    </Text>
</View>


                <TouchableHighlight
                    style={styles.button}
                    onPress={() => {
                        setIsModalVisible(!isModalVisible);
                    }}
                >
                    <Text style={styles.buttonText}>Got it!</Text>
                </TouchableHighlight>
            </View>
        </View>
        </View>
    </Modal>

    {/* Error Message Modal */}
    <Modal
        animationType="slide"
        transparent={true}
        visible={isErrorModalVisible}
        onRequestClose={() => {
          setIsErrorModalVisible(false);
        }}
      >
        <View style={styles.overlay}>
          <View style={styles.centeredView}>
            <View style={styles.modalView}>
              <Text style={styles.afflictionText}>{errorModalMessage}</Text>
              <TouchableHighlight
                style={styles.button}
                onPress={() => {
                  setIsErrorModalVisible(false);
                }}
              >
                <Text style={styles.buttonText}>Close</Text>
              </TouchableHighlight>
            </View>
          </View>
        </View>
      </Modal>
          
          {/* {afflictionPercentage !== null && (
            <View style={{ marginTop: 20 }}>
              <Text>Affliction Percentage: {afflictionPercentage}%</Text>
            </View>
          )} */}
    
          {/* Back Button */}
          {/* <Button
            title="Back"
            onPress={() => navigation.goBack()} // Navigate back
          /> */}
        </View>
         
      );
    };
    
    const styles = StyleSheet.create({
    
      container: {
        flexDirection: 'row',
        paddingHorizontal: 5
      },
    
      imageBox: {
        // backgroundColor: 'red',
        width:300,
        height: 300,
        marginBottom: 20,
             
      },

      
    
    
      button: {
        backgroundColor: '#87B673',
        paddingHorizontal: 20,
        paddingVertical: 8,
        borderRadius: 8,
        // borderWidth: 0,
        // borderColor: 'black',
        marginVertical: 10,
        marginHorizontal: 5,
        // width: 150,
        shadowColor: 'black',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.8,
        shadowRadius: 4,
        // elevation: 10,
        // height: 50,
      },
    
      buttonText: {
        color: '#e8fbe8',
        fontSize: 20,
        fontWeight: '800',
        textAlign: 'center',
        // marginTop: 25,
      },
    
      customButton: {
        backgroundColor: '#ebebeb',
        borderColor: '#87B673',
        paddingHorizontal: 10,
        paddingVertical: 8,
        borderRadius: 8,
        borderWidth: 2,
        // borderColor: 'black',
        marginVertical: 10,
        marginHorizontal: 5,
        // width: 150,
        shadowColor: 'black',
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.8,
        shadowRadius: 4,
      },
      customButtonText: {
        color: '#87B673',
        fontSize: 18,
        fontWeight: 'bold',
        textAlign: 'center',
      },
    
      placeholderImage: {
        width: 250,
        height: 250,
        resizeMode: 'cover',
        marginBottom: 10,
      },
      placeholderText: {
        fontSize: 23,
        color: '#888', // Placeholder text color
        textAlign: 'center',

      },
      cameraButtons: {
        flexDirection: 'row',
        justifyContent: 'space-around',
        width: '100%',
        marginBottom: 20,
        // position:'absolute'
      },
      captureButton: {
        fontSize: 18,
        color: '#888'
      },
      cancelButton: {
        fontSize: 18,
        color: '#888'
      },

      closeButton: {
        position: 'absolute',
        top: 5,
        right: 5,
        backgroundColor: 'rgba(255,255,255,0.6)',
        borderRadius: 15,
        width: 30,
        height: 30,
        justifyContent: 'center',
        alignItems: 'center',
      },
      closeButtonText: {
        fontSize: 20,
        fontWeight: 'bold',
        color: '#888',
      },

      //for pop up window
      centeredView: {
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
        marginTop: 22
      },
      modalView: {
        margin: 20,
        backgroundColor: "white",
        borderRadius: 20,
        padding: 35,
        alignItems: "center",
        shadowColor: "#000",
        shadowOffset: {
          width: 0,
          height: 2
        },
        shadowOpacity: 0.25,
        shadowRadius: 4,
        elevation: 5
      },
      modalImage: {
        width: 200,
        height: 200,
        resizeMode: 'cover',
        marginBottom: 20,
        borderRadius: 8,
    },
    afflictionText: {
      fontSize: 24, // Increased font size
      marginBottom: 15,
      textAlign: 'center'
  },

      openButton: {
        backgroundColor: "#F194FF",
        borderRadius: 20,
        padding: 10,
        elevation: 2
      },
      textStyle: {
        color: "white",
        fontWeight: "bold",
        textAlign: "center"
      },
      overlay: {
        flex: 1,
        backgroundColor: 'rgba(0, 0, 0, 0.7)', // This dims the background
        justifyContent: 'center',
        alignItems: 'center',
      },

      resultBox: {
        padding: 10,
        backgroundColor: "#E8FBE8",
        borderColor: "#B8DAB8",
        borderWidth: 1,
        borderRadius: 8,
        marginBottom: 10,
        alignItems: 'center'
    },
    recommendationBox: {
        flexDirection: 'row',
        padding: 10,
        backgroundColor: "#89C689",
        borderColor: "#569856",
        borderWidth: 1,
        borderRadius: 8,
        alignItems: 'center',
        justifyContent: 'space-between'
    },
    })
    
    export default AreaCalculationScreen;
